@@ -97,11 +97,11 @@ Usage::
     list_resource_data_sync_paginator: ListResourceDataSyncPaginator = client.get_paginator("list_resource_data_sync")
     ```
 """
-from mypy_boto3_ssm.client import SSMClient, SSMClient as Client
+from mypy_boto3_ssm.client import SSMClient
 from mypy_boto3_ssm.paginator import (
     DescribeActivationsPaginator,
-    DescribeAssociationExecutionTargetsPaginator,
     DescribeAssociationExecutionsPaginator,
+    DescribeAssociationExecutionTargetsPaginator,
     DescribeAutomationExecutionsPaginator,
     DescribeAutomationStepExecutionsPaginator,
     DescribeAvailablePatchesPaginator,
@@ -109,18 +109,18 @@ from mypy_boto3_ssm.paginator import (
     DescribeEffectivePatchesForPatchBaselinePaginator,
     DescribeInstanceAssociationsStatusPaginator,
     DescribeInstanceInformationPaginator,
+    DescribeInstancePatchesPaginator,
     DescribeInstancePatchStatesForPatchGroupPaginator,
     DescribeInstancePatchStatesPaginator,
-    DescribeInstancePatchesPaginator,
     DescribeInventoryDeletionsPaginator,
+    DescribeMaintenanceWindowExecutionsPaginator,
     DescribeMaintenanceWindowExecutionTaskInvocationsPaginator,
     DescribeMaintenanceWindowExecutionTasksPaginator,
-    DescribeMaintenanceWindowExecutionsPaginator,
     DescribeMaintenanceWindowSchedulePaginator,
-    DescribeMaintenanceWindowTargetsPaginator,
-    DescribeMaintenanceWindowTasksPaginator,
     DescribeMaintenanceWindowsForTargetPaginator,
     DescribeMaintenanceWindowsPaginator,
+    DescribeMaintenanceWindowTargetsPaginator,
+    DescribeMaintenanceWindowTasksPaginator,
     DescribeParametersPaginator,
     DescribePatchBaselinesPaginator,
     DescribePatchGroupsPaginator,
@@ -129,18 +129,20 @@ from mypy_boto3_ssm.paginator import (
     GetInventorySchemaPaginator,
     GetParameterHistoryPaginator,
     GetParametersByPathPaginator,
-    ListAssociationVersionsPaginator,
     ListAssociationsPaginator,
+    ListAssociationVersionsPaginator,
     ListCommandInvocationsPaginator,
     ListCommandsPaginator,
     ListComplianceItemsPaginator,
     ListComplianceSummariesPaginator,
-    ListDocumentVersionsPaginator,
     ListDocumentsPaginator,
+    ListDocumentVersionsPaginator,
     ListResourceComplianceSummariesPaginator,
     ListResourceDataSyncPaginator,
 )
 
+Client = SSMClient
+
 
 __all__ = (
     "Client",
